==> nibiru-proto-0.14.1.tar.gz: nibiru-proto-0.14.1/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nibiru_proto',
 'nibiru_proto.proto',
 'nibiru_proto.proto.common',
 'nibiru_proto.proto.confio',
 'nibiru_proto.proto.cosmos.auth.v1beta1',
 'nibiru_proto.proto.cosmos.authz.v1beta1',
 'nibiru_proto.proto.cosmos.bank.v1beta1',
 'nibiru_proto.proto.cosmos.base.abci.v1beta1',
 'nibiru_proto.proto.cosmos.base.kv.v1beta1',
 'nibiru_proto.proto.cosmos.base.query.v1beta1',
 'nibiru_proto.proto.cosmos.base.reflection.v1beta1',
 'nibiru_proto.proto.cosmos.base.reflection.v2alpha1',
 'nibiru_proto.proto.cosmos.base.snapshots.v1beta1',
 'nibiru_proto.proto.cosmos.base.store.v1beta1',
 'nibiru_proto.proto.cosmos.base.tendermint.v1beta1',
 'nibiru_proto.proto.cosmos.base.v1beta1',
 'nibiru_proto.proto.cosmos.capability.v1beta1',
 'nibiru_proto.proto.cosmos.crisis.v1beta1',
 'nibiru_proto.proto.cosmos.crypto.ed25519',
 'nibiru_proto.proto.cosmos.crypto.multisig',
 'nibiru_proto.proto.cosmos.crypto.multisig.v1beta1',
 'nibiru_proto.proto.cosmos.crypto.secp256k1',
 'nibiru_proto.proto.cosmos.crypto.secp256r1',
 'nibiru_proto.proto.cosmos.distribution.v1beta1',
 'nibiru_proto.proto.cosmos.evidence.v1beta1',
 'nibiru_proto.proto.cosmos.feegrant.v1beta1',
 'nibiru_proto.proto.cosmos.genutil.v1beta1',
 'nibiru_proto.proto.cosmos.gov.v1beta1',
 'nibiru_proto.proto.cosmos.mint.v1beta1',
 'nibiru_proto.proto.cosmos.params.v1beta1',
 'nibiru_proto.proto.cosmos.slashing.v1beta1',
 'nibiru_proto.proto.cosmos.staking.v1beta1',
 'nibiru_proto.proto.cosmos.tx.signing.v1beta1',
 'nibiru_proto.proto.cosmos.tx.v1beta1',
 'nibiru_proto.proto.cosmos.upgrade.v1beta1',
 'nibiru_proto.proto.cosmos.vesting.v1beta1',
 'nibiru_proto.proto.cosmos_proto',
 'nibiru_proto.proto.dex.v1',
 'nibiru_proto.proto.epochs',
 'nibiru_proto.proto.gogoproto',
 'nibiru_proto.proto.google.api',
 'nibiru_proto.proto.google.protobuf',
 'nibiru_proto.proto.incentivization.v1',
 'nibiru_proto.proto.lockup.v1',
 'nibiru_proto.proto.oracle.v1beta1',
 'nibiru_proto.proto.perp.v1',
 'nibiru_proto.proto.pricefeed',
 'nibiru_proto.proto.stablecoin',
 'nibiru_proto.proto.tendermint.abci',
 'nibiru_proto.proto.tendermint.crypto',
 'nibiru_proto.proto.tendermint.libs.bits',
 'nibiru_proto.proto.tendermint.p2p',
 'nibiru_proto.proto.tendermint.types',
 'nibiru_proto.proto.tendermint.version',
 'nibiru_proto.proto.vpool.v1']

package_data = \
{'': ['*']}

install_requires = \
['asyncio>=3.4.3,<4.0.0',
 'bech32>=1.2.0,<2.0.0',
 'grpcio-tools==1.48.0',
 'grpcio>=1.48.0,<2.0.0',
 'mypy-protobuf>=3.2.0,<4.0.0',
 'protobuf==3.20.1']

setup_kwargs = {
    'name': 'nibiru-proto',
    'version': '0.14.1',
    'description': '',
    'long_description': None,
    'author': 'Nibiru Chain',
    'author_email': 'dev@nibiru.fi',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)

==> nibiru-proto-0.15.0a1.tar.gz: nibiru-proto-0.15.0a1/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['nibiru_proto',
 'nibiru_proto.proto',
 'nibiru_proto.proto.common',
 'nibiru_proto.proto.confio',
 'nibiru_proto.proto.cosmos.auth.v1beta1',
 'nibiru_proto.proto.cosmos.authz.v1beta1',
 'nibiru_proto.proto.cosmos.bank.v1beta1',
 'nibiru_proto.proto.cosmos.base.abci.v1beta1',
 'nibiru_proto.proto.cosmos.base.kv.v1beta1',
 'nibiru_proto.proto.cosmos.base.query.v1beta1',
 'nibiru_proto.proto.cosmos.base.reflection.v1beta1',
 'nibiru_proto.proto.cosmos.base.reflection.v2alpha1',
 'nibiru_proto.proto.cosmos.base.snapshots.v1beta1',
 'nibiru_proto.proto.cosmos.base.store.v1beta1',
 'nibiru_proto.proto.cosmos.base.tendermint.v1beta1',
 'nibiru_proto.proto.cosmos.base.v1beta1',
 'nibiru_proto.proto.cosmos.capability.v1beta1',
 'nibiru_proto.proto.cosmos.crisis.v1beta1',
 'nibiru_proto.proto.cosmos.crypto.ed25519',
 'nibiru_proto.proto.cosmos.crypto.multisig',
 'nibiru_proto.proto.cosmos.crypto.multisig.v1beta1',
 'nibiru_proto.proto.cosmos.crypto.secp256k1',
 'nibiru_proto.proto.cosmos.crypto.secp256r1',
 'nibiru_proto.proto.cosmos.distribution.v1beta1',
 'nibiru_proto.proto.cosmos.evidence.v1beta1',
 'nibiru_proto.proto.cosmos.feegrant.v1beta1',
 'nibiru_proto.proto.cosmos.genutil.v1beta1',
 'nibiru_proto.proto.cosmos.gov.v1beta1',
 'nibiru_proto.proto.cosmos.mint.v1beta1',
 'nibiru_proto.proto.cosmos.params.v1beta1',
 'nibiru_proto.proto.cosmos.slashing.v1beta1',
 'nibiru_proto.proto.cosmos.staking.v1beta1',
 'nibiru_proto.proto.cosmos.tx.signing.v1beta1',
 'nibiru_proto.proto.cosmos.tx.v1beta1',
 'nibiru_proto.proto.cosmos.upgrade.v1beta1',
 'nibiru_proto.proto.cosmos.vesting.v1beta1',
 'nibiru_proto.proto.cosmos_proto',
 'nibiru_proto.proto.dex.v1',
 'nibiru_proto.proto.epochs',
 'nibiru_proto.proto.gogoproto',
 'nibiru_proto.proto.google.api',
 'nibiru_proto.proto.google.protobuf',
 'nibiru_proto.proto.incentivization.v1',
 'nibiru_proto.proto.lockup.v1',
 'nibiru_proto.proto.oracle.v1beta1',
 'nibiru_proto.proto.perp.v1',
 'nibiru_proto.proto.pricefeed',
 'nibiru_proto.proto.stablecoin',
 'nibiru_proto.proto.tendermint.abci',
 'nibiru_proto.proto.tendermint.crypto',
 'nibiru_proto.proto.tendermint.libs.bits',
 'nibiru_proto.proto.tendermint.p2p',
 'nibiru_proto.proto.tendermint.types',
 'nibiru_proto.proto.tendermint.version',
 'nibiru_proto.proto.vpool.v1']

package_data = \
{'': ['*']}

install_requires = \
['asyncio>=3.4.3,<4.0.0',
 'bech32>=1.2.0,<2.0.0',
 'grpcio-tools==1.48.0',
 'grpcio>=1.48.0,<2.0.0',
 'mypy-protobuf>=3.2.0,<4.0.0',
 'protobuf==3.20.1']

setup_kwargs = {
    'name': 'nibiru-proto',
    'version': '0.15.0a1',
    'description': '',
    'long_description': None,
    'author': 'Nibiru Chain',
    'author_email': 'dev@nibiru.fi',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.9,<4.0',
}


setup(**setup_kwargs)
